@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use GD::Simple;
 
-our $VERSION = "0.3";
+our $VERSION = "0.32";
 
 sub new {
 	my ($class, @args) = @_;
@@ -218,6 +218,12 @@ This is the method responsible for generating the image file with png extension.
 
 Leprevost, C<< <leprevostfv at gmail.com> >>
 
+=begin HTML
+
+<p><img src="https://github.com/Leprevost/Bio-Tools-Alignment-Overview/raw/master/zenodo.9798.png" alt="DOI" /></p>
+
+=end HTML
+
 =head1 BUGS
 
 Please report any bugs or feature requests to C<bug-bio-tools-alignment-overview at rt.cpan.org>, or through
